@@ -576,6 +576,9 @@ module Loofah
                                             "list-style-type",
                                             "max-width",
                                             "overflow",
+                                            "page-break-after",
+                                            "page-break-before",
+                                            "page-break-inside",
                                             "pause",
                                             "pause-after",
                                             "pause-before",
